::: pynyaa._types.CategoryID
::: pynyaa._types.CategoryLiteral
::: pynyaa._types.CategoryName
::: pynyaa._types.CategoryValue
::: pynyaa._types.MagnetUrl
::: pynyaa._types.SortByLiteral
::: pynyaa._types.UTCDateTime
